@@ -5,6 +5,7 @@ from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support.ui import Select
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.common.exceptions import TimeoutException
+from re import match
 
 class Sei:
 
@@ -41,7 +42,7 @@ class Sei:
         self.driver.switch_to.default_content()
         pesquisa = WebDriverWait(self.driver, 3).until(EC.presence_of_element_located((By.ID, "txtPesquisaRapida")))
         pesquisa.clear()
-        pesquisa.send_keys('' + numero_sei)
+        pesquisa.send_keys(str(numero_sei))
         formPesquisaRapida = WebDriverWait(self.driver, 3).until(
             EC.presence_of_element_located((By.ID, "frmProtocoloPesquisaRapida")))
         formPesquisaRapida.submit()
@@ -51,7 +52,11 @@ class Sei:
         ifrVisualizacao = WebDriverWait(self.driver, 3).until(EC.presence_of_element_located((By.ID, "ifrVisualizacao")))
         self.driver.switch_to.frame(ifrVisualizacao)
         informacao = WebDriverWait(self.driver, 3).until(EC.presence_of_element_located((By.ID, "divInformacao")))
-        aberto = area in informacao.text
+        print(informacao.text)
+        matches = match('(?im)' + area + '[^0-9a-z]+',informacao.text)
+        aberto = False
+        if matches:
+            aberto = True
         self.driver.switch_to.default_content()
         return aberto
 
@@ -78,13 +83,13 @@ class Sei:
         select = Select(self.driver.find_element_by_id('selInfraUnidades'))
         all_selected_options = select.all_selected_options
         for option in all_selected_options:
-            if area in option.text:
+            if area == option.text:
                 return True
 
         select = Select(self.driver.find_element_by_id('selInfraUnidades'))
         options = select.options
         for option in options:
-            if area in option.text:
+            if area == option.text:
                 select.select_by_visible_text(area)
                 Select(WebDriverWait(self.driver, 3).until(EC.presence_of_element_located((By.ID, 'selInfraUnidades'))))
                 return True
@@ -114,12 +119,13 @@ class Sei:
         self.driver.switch_to.frame(ifrVisualizacao)
         informacao = WebDriverWait(self.driver, 3).until(EC.presence_of_element_located((By.ID, "divInformacao")))
         sobrestado = 'sobrestado' in informacao.text
-        naArea = area in informacao.text if area else None
+        mensagem = informacao.text
+
         self.driver.switch_to.default_content()
         if area:
-            return sobrestado, informacao.text
+            return sobrestado, mensagem
         else:
-            return sobrestado, naArea
+            return sobrestado, match('(?im)' + area + '[^0-9a-z]+',mensagem) != None
 
     def sobrestar_processo(self, processo, motivo):
         self.go_to(processo)
@@ -202,6 +208,38 @@ class Sei:
         finally:
             self.driver.switch_to.default_content()
 
+    def get_documento_element_by_id(self,documento,id):
+        self.go_to(documento)
+
+        try:
+            ifrVisualizacao = WebDriverWait(self.driver, 3).until(
+                EC.presence_of_element_located((By.ID, "ifrVisualizacao")))
+            self.driver.switch_to.frame(ifrVisualizacao)
+            ifrArvoreHtml = WebDriverWait(self.driver, 3).until(
+                EC.presence_of_element_located((By.ID, "ifrArvoreHtml")))
+            self.driver.switch_to.frame(ifrArvoreHtml)
+            return self.driver.driver.find_element_by_id(id)
+        except:
+            raise Exception('Conteúdo do documento %s não encontrado.' % documento)
+        finally:
+            self.driver.switch_to.default_content()
+
+    def get_documento_element_by_xpath(self,documento,xpath):
+        self.go_to(documento)
+
+        try:
+            ifrVisualizacao = WebDriverWait(self.driver, 3).until(
+                EC.presence_of_element_located((By.ID, "ifrVisualizacao")))
+            self.driver.switch_to.frame(ifrVisualizacao)
+            ifrArvoreHtml = WebDriverWait(self.driver, 3).until(
+                EC.presence_of_element_located((By.ID, "ifrArvoreHtml")))
+            self.driver.switch_to.frame(ifrArvoreHtml)
+            return self.driver.driver.find_element_by_xpath(xpath)
+        except:
+            raise Exception('Conteúdo do documento %s não encontrado.' % documento)
+        finally:
+            self.driver.switch_to.default_content()
+
     def close(self):
         self.driver.close()
         self.driver.quit()
\ No newline at end of file
